Request

Enum Request 

#[non_exhaustive]
pub enum Request<'a> { Destroy, GetXdgDialog { toplevel: XdgToplevel, }, }

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Destroy

destroy the dialog manager object

Destroys the xdg_wm_dialog_v1 object. This does not affect the xdg_dialog_v1 objects generated through it.

This is a destructor, once sent this object cannot be used any longer.



GetXdgDialog

create a dialog object

Creates a xdg_dialog_v1 object for the given toplevel. See the interface description for more details.

Compositors must raise an already_used error if clients attempt to create multiple xdg_dialog_v1 objects for the same xdg_toplevel.

Fields

toplevel: XdgToplevel

Implementations

Source

impl<'a> Request<'a>

pub fn opcode(&self) -> u16

Get the opcode number of this message