pub struct XdgWmDialogV1 { /* private fields */ }Expand description
create dialogs related to other toplevels
The xdg_wm_dialog_v1 interface is exposed as a global object allowing to register surfaces with a xdg_toplevel role as “dialogs” relative to another toplevel.
The compositor may let this relation influence how the surface is placed, displayed or interacted with.
Warning! The protocol described in this file is currently in the testing phase. Backward compatible changes may be added together with the corresponding interface version bump. Backward incompatible changes can only be done by creating a new major version of the extension.
This interface has no events.
Implementations
Sourceimpl XdgWmDialogV1
impl XdgWmDialogV1
Sourcepub fn destroy(&self)
pub fn destroy(&self)
destroy the dialog manager object
Destroys the xdg_wm_dialog_v1 object. This does not affect the xdg_dialog_v1 objects generated through it.
Sourcepub fn get_xdg_dialog<U, D: 'static>(
&self,
toplevel: &XdgToplevel,
qh: &QueueHandle<D>,
udata: U,
) -> XdgDialogV1
pub fn get_xdg_dialog<U, D: 'static>( &self, toplevel: &XdgToplevel, qh: &QueueHandle<D>, udata: U, ) -> XdgDialogV1
create a dialog object
Creates a xdg_dialog_v1 object for the given toplevel. See the interface description for more details.
Compositors must raise an already_used error if clients attempt to create multiple xdg_dialog_v1 objects for the same xdg_toplevel.